@@ -13,6 +13,7 @@ import re
 import sys
 from decimal import Decimal
 from io import BytesIO
+from itertools import islice
 from ssl import CERT_NONE, CERT_OPTIONAL, CERT_REQUIRED
 
 from thrift.protocol import TBinaryProtocol, TMultiplexedProtocol
@@ -323,7 +324,7 @@ class Cursor(common.DBAPICursor):
         _logger.info("fetching all")
         return self._fetch_all()
 
-    def fetchone(self):
+    def fetchoneOld(self):
         _logger.info("fetching one")
         if len(self._batch) == 0:
             self.fetch_batch()
@@ -338,6 +339,21 @@ class Cursor(common.DBAPICursor):
             self.rows_count = 0
         return row
 
+    def fetchone(self):
+        _logger.info("fetch returning the batch itself")
+        if len(self._batch) == 0:
+            self.fetch_batch()
+            if len(self._batch) == 0:
+                return None
+        self.rows_count += len(self._batch)
+        if self.rows_count <= 1000:
+            row = self._batch
+        else:
+            row = None
+            # reset row counter for next query execution
+            self.rows_count = 0
+        return row
+
     # def fetchone(self):
     #     _logger.info("fetching one")
     #     client = self.connection.client
@@ -392,9 +408,10 @@ if __name__ == '__main__':
     cursor.execute("SELECT c_first_name FROM store_returns AS sr, customer AS c WHERE c.c_customer_sk = sr.sr_customer_sk AND c.c_first_name = 'Susan' ORDER BY sr_returned_date_sk;")
     bdata = cursor.fetchone()
     try:
-        while bdata:
+        while len(bdata) > 0:
             print(len(bdata))
             bdata = cursor.fetchone()
+            list(islice(iter(bdata, None), 10000))
     except Exception as e:
         cursor.close()
 
